%% Read and solve the non-linear credibility model
% by Jaromir Benes
%
% This m-file is fairly standard. We read the endogenous credibility model
% file, |credibility.model|, assign some parameters, compute steady state,
% solve the model, and save everything for future use. These steps are
% explained in other tutorials in more detail.

%% Housekeeping

%clear;
close all;
clc;
irisrequired 20120219;

%% Load and calibrate the endogenous credibility model

m = model('credibility.model');

m.alp = 0.5;
m.sgm = 0.1;
m.bet = 0.99;
m.gam = 0.09;
m.del = 0.4;
m.the = 0.80;
m.kap = 4;
m.phi = 0;
m.tau = 3;
m.rho = 2;
m.psi = 0.4;
m.omg = 1.3;

%% Compute steady state and solve the model

m = sstate(m);

get(m,'sstate')

m = solve(m);

disp(m)

%% Save everything for future use
% ================================

save read_model.mat;

%% Help on IRIS functions used in this m-file
% ============================================
%
% Use either `help` to display help in the command window, or `idoc`
% to display help in an HTML browser window.
%
%    help model
%    help model/model
%    help model/subsasgn
%    help model/sstate
%    help model/get
%    help model/solve
